@@ -5,12 +5,17 @@ data("pbmc_small")
 set.seed(42)
 
 test_that("arrange", {
-  pbmc_small_pca_arranged <- pbmc_small |> arrange(nFeature_RNA) |> Seurat::ScaleData() |> Seurat::FindVariableFeatures() |> Seurat::RunPCA()
-  pbmc_small_pca <- pbmc_small |> Seurat::ScaleData() |> Seurat::FindVariableFeatures() |> Seurat::RunPCA()
-  expect_equal(
-    Seurat::VariableFeatures(pbmc_small_pca_arranged),
-    Seurat::VariableFeatures(pbmc_small_pca)
-  )
+  
+  pbmc_small |> 
+    arrange(nFeature_RNA) |> 
+    expect_warning(regexp = "`arrange\\(\\)` was deprecated in tidyseurat .*")
+  
+  # pbmc_small_pca_arranged <- pbmc_small |> arrange(nFeature_RNA) |> Seurat::ScaleData() |> Seurat::FindVariableFeatures() |> Seurat::RunPCA()
+  # pbmc_small_pca <- pbmc_small |> Seurat::ScaleData() |> Seurat::FindVariableFeatures() |> Seurat::RunPCA()
+  # expect_equal(
+  #   Seurat::VariableFeatures(pbmc_small_pca_arranged),
+  #   Seurat::VariableFeatures(pbmc_small_pca)
+  # )
   
   # # Failing only for ATLAS CRAN, but succeding for the rest
   # expect_equal(
@@ -22,12 +27,13 @@ test_that("arrange", {
   #   pbmc_small_pca_arranged |> as_tibble() |>dplyr::slice_head(n = 1),
   #   pbmc_small_pca |> as_tibble() |> dplyr::slice_min(nFeature_RNA, n = 1)
   # )
+
 })
 
 test_that("bind_cols", {
   pbmc_small_bind <- pbmc_small |> select(nCount_RNA, nFeature_RNA)
   pbmc_small |>
-    bind_cols(pbmc_small_bind) |>
+    ttservice::bind_cols(pbmc_small_bind) |>
     select(nCount_RNA...2, nFeature_RNA...3) |>
     ncol() |>
     expect_equal(2)
@@ -107,14 +113,10 @@ test_that("sample_n", {
 })
 
 test_that("slice_sample", {
-    pbmc_small |>
-        slice_sample(n=50) |>
-        ncol() |>
-        expect_equal(50)
-    pbmc_small |>
-      slice_sample(n=0) |>
-      expect_error() |>
-      expect_no_warning()
+  pbmc_small |>
+    slice_sample(n = 50) |>
+    ncol() |>
+    expect_equal(50)
 })
 
 test_that("slice_head", {
@@ -144,10 +146,12 @@ test_that("slice_min", {
     slice_min(nFeature_RNA, n = 5) |>
     ncol() |>
     expect_equal(5)
-  expect_equal(
-    pbmc_small |> as_tibble() |> arrange(nFeature_RNA) |> head(n = 5) %>% pull(.cell),
-    pbmc_small |> slice_min(nFeature_RNA, n = 5) |> colnames()
-  )
+  
+  # Arrange is deprecated
+  # expect_equal(
+  #   pbmc_small |> as_tibble() |> arrange(nFeature_RNA) |> head(n = 5) %>% pull(.cell),
+  #   pbmc_small |> slice_min(nFeature_RNA, n = 5) |> colnames()
+  # )
 })
 
 test_that("slice_max", {
@@ -155,10 +159,12 @@ test_that("slice_max", {
     slice_max(nFeature_RNA, n = 5) |>
     ncol() |>
     expect_equal(5)
-  expect_equal(
-    pbmc_small |> as_tibble() |> arrange(desc(nFeature_RNA)) |> head(n = 5) %>% pull(.cell),
-    pbmc_small |> slice_max(nFeature_RNA, n = 5) |> colnames()
-  )
+  
+  # Arrange is deprecated
+  # expect_equal(
+  #   pbmc_small |> as_tibble() |> arrange(desc(nFeature_RNA)) |> head(n = 5) %>% pull(.cell),
+  #   pbmc_small |> slice_max(nFeature_RNA, n = 5) |> colnames()
+  # )
 })
 
 test_that("slice_min slice_max tibble input for order_by", {
